pub struct CodecRankingComponentModel {}Trait Implementations
Sourceimpl Component for CodecRankingComponentModel
impl Component for CodecRankingComponentModel
Sourcefn update_view(
&self,
widgets: &mut Self::Widgets,
sender: ComponentSender<Self>,
)
fn update_view( &self, widgets: &mut Self::Widgets, sender: ComponentSender<Self>, )
Update the view to represent the updated model.
Sourcetype Init = CodecRankingComponentInit
type Init = CodecRankingComponentInit
The parameter used to initialize the component.
Sourcetype Input = CodecRankingComponentInput
type Input = CodecRankingComponentInput
The message type that the component accepts as inputs.
Sourcetype Output = CodecRankingComponentOutput
type Output = CodecRankingComponentOutput
The message type that the component provides as outputs.
Sourcetype CommandOutput = ()
type CommandOutput = ()
Messages which are received from commands executing in the background.
Sourcetype Root = PreferencesGroup
type Root = PreferencesGroup
The top-level widget of the component.
Sourcetype Widgets = CodecRankingComponentModelWidgets
type Widgets = CodecRankingComponentModelWidgets
The type that’s used for storing widgets created for this component.
Sourcefn init(
init: Self::Init,
root: Self::Root,
sender: ComponentSender<Self>,
) -> ComponentParts<Self>
fn init( init: Self::Init, root: Self::Root, sender: ComponentSender<Self>, ) -> ComponentParts<Self>
Creates the initial model and view, docking it into the component.
Sourcefn update(
&mut self,
msg: Self::Input,
sender: ComponentSender<Self>,
_: &Self::Root,
)
fn update( &mut self, msg: Self::Input, sender: ComponentSender<Self>, _: &Self::Root, )
Processes inputs received by the component.
Sourcefn builder() -> ComponentBuilder<Self>
fn builder() -> ComponentBuilder<Self>
Create a builder for this component.
Sourcefn update_cmd(
&mut self,
message: Self::CommandOutput,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update_cmd( &mut self, message: Self::CommandOutput, sender: ComponentSender<Self>, root: &Self::Root, )
Defines how the component should respond to command updates.
Sourcefn update_cmd_with_view(
&mut self,
widgets: &mut Self::Widgets,
message: Self::CommandOutput,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update_cmd_with_view( &mut self, widgets: &mut Self::Widgets, message: Self::CommandOutput, sender: ComponentSender<Self>, root: &Self::Root, )
Updates the model and view upon completion of a command. Read more
Sourcefn update_with_view(
&mut self,
widgets: &mut Self::Widgets,
message: Self::Input,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update_with_view( &mut self, widgets: &mut Self::Widgets, message: Self::Input, sender: ComponentSender<Self>, root: &Self::Root, )
Updates the model and view when a new input is received. Read more