pub struct MessageDialog { /* private fields */ }Trait Implementations
Sourceimpl Component for MessageDialog
impl Component for MessageDialog
Sourcefn update_view(
&self,
widgets: &mut Self::Widgets,
sender: ComponentSender<Self>,
)
fn update_view( &self, widgets: &mut Self::Widgets, sender: ComponentSender<Self>, )
Update the view to represent the updated model.
Sourcetype Input = MessageDialogInput
type Input = MessageDialogInput
The message type that the component accepts as inputs.
Sourcetype Output = MessageDialogOutput
type Output = MessageDialogOutput
The message type that the component provides as outputs.
Sourcetype CommandOutput = ()
type CommandOutput = ()
Messages which are received from commands executing in the background.
Sourcetype Widgets = MessageDialogWidgets
type Widgets = MessageDialogWidgets
The type that’s used for storing widgets created for this component.
Sourcefn init(
_init: (),
root: Self::Root,
sender: ComponentSender<Self>,
) -> ComponentParts<Self>
fn init( _init: (), root: Self::Root, sender: ComponentSender<Self>, ) -> ComponentParts<Self>
Creates the initial model and view, docking it into the component.
Sourcefn update(
&mut self,
msg: Self::Input,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update( &mut self, msg: Self::Input, sender: ComponentSender<Self>, root: &Self::Root, )
Processes inputs received by the component.
Sourcefn builder() -> ComponentBuilder<Self>
fn builder() -> ComponentBuilder<Self>
Create a builder for this component.
Sourcefn update_cmd(
&mut self,
message: Self::CommandOutput,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update_cmd( &mut self, message: Self::CommandOutput, sender: ComponentSender<Self>, root: &Self::Root, )
Defines how the component should respond to command updates.
Sourcefn update_cmd_with_view(
&mut self,
widgets: &mut Self::Widgets,
message: Self::CommandOutput,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update_cmd_with_view( &mut self, widgets: &mut Self::Widgets, message: Self::CommandOutput, sender: ComponentSender<Self>, root: &Self::Root, )
Updates the model and view upon completion of a command. Read more
Sourcefn update_with_view(
&mut self,
widgets: &mut Self::Widgets,
message: Self::Input,
sender: ComponentSender<Self>,
root: &Self::Root,
)
fn update_with_view( &mut self, widgets: &mut Self::Widgets, message: Self::Input, sender: ComponentSender<Self>, root: &Self::Root, )
Updates the model and view when a new input is received. Read more